@@ -207,6 +207,11 @@ class UpnpDevice:
         """Get the manufacturer of this device."""
         return self.device_info.manufacturer
 
+    @property
+    def manufacturer_url(self) -> Optional[str]:
+        """Get the manufacturer URL of this device."""
+        return self.device_info.manufacturer_url
+
     @property
     def model_description(self) -> Optional[str]:
         """Get the model description of this device."""
@@ -222,6 +227,11 @@ class UpnpDevice:
         """Get the model number of this device."""
         return self.device_info.model_number
 
+    @property
+    def model_url(self) -> Optional[str]:
+        """Get the model URL of this device."""
+        return self.device_info.model_url
+
     @property
     def serial_number(self) -> Optional[str]:
         """Get the serial number of this device."""
@@ -232,6 +242,16 @@ class UpnpDevice:
         """Get UDN of this device."""
         return self.device_info.udn
 
+    @property
+    def upc(self) -> Optional[str]:
+        """Get UPC of this device."""
+        return self.device_info.upc
+
+    @property
+    def presentation_url(self) -> Optional[str]:
+        """Get presentationURL of this device."""
+        return self.device_info.presentation_url
+
     @property
     def device_url(self) -> str:
         """Get the URL of this device."""
@@ -759,6 +779,8 @@ T = TypeVar("T")  # pylint: disable=invalid-name
 class UpnpStateVariable(Generic[T]):
     """Representation of a State Variable."""
 
+    # pylint: disable=too-many-instance-attributes
+
     UPNP_VALUE_ERROR = object()
 
     def __init__(
